@@ -2,13 +2,13 @@ package Bat::Interpreter::Delegate::FileStore::LocalFileSystem;
 
 use utf8;
 
-use Moose;
+use Moo;
 use Path::Tiny;
 use namespace::autoclean;
 
 with 'Bat::Interpreter::Role::FileStore';
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub get_contents {
     my $self     = shift();
@@ -31,7 +31,7 @@ Bat::Interpreter::Delegate::FileStore::LocalFileSystem
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
